@@ -5,7 +5,7 @@ from sqlalchemy_utils import EmailType
 from wtforms.validators import (
     Email, InputRequired, DataRequired, Optional, NumberRange, Length
 )
-from wtforms_alchemy import Unique, ModelForm, ClassMap
+from wtforms_alchemy import Unique, ModelForm, ClassMap, model_form_factory
 from wtforms_components import TimeRange, DateRange
 from tests import ModelFormTestCase
 
@@ -29,8 +29,11 @@ class TestAutoAssignedValidators(ModelFormTestCase):
             id = sa.Column(sa.Integer, primary_key=True)
             test_column = sa.Column(sa.Unicode(255), unique=True)
 
+        Form = model_form_factory()
+        assert not Form.get_session
+
         with raises(Exception):
-            class ModelTestForm(ModelForm):
+            class ModelTestForm(Form):
                 class Meta:
                     model = ModelTest
 
@@ -114,7 +117,7 @@ class TestAutoAssignedValidators(ModelFormTestCase):
         self.init(nullable=False, default=u'default')
         self.assert_not_required('test_column')
 
-    def test_assigns_not_nullable_integers_as_optional(self):
+    def test_assigns_nullable_integers_as_optional(self):
         self.init(sa.Integer, nullable=True)
         self.assert_optional('test_column')
 
@@ -226,6 +229,20 @@ class TestAutoAssignedValidators(ModelFormTestCase):
         form = ModelTestForm()
         assert form.test_column.validators[1].message == 'Wrong length'
 
+    def test_override_optional_validator_as_none(self):
+        class ModelTest(self.base):
+            __tablename__ = 'model_test'
+            id = sa.Column(sa.Integer, primary_key=True)
+            test_column = sa.Column(sa.Boolean, nullable=True)
+
+        class ModelTestForm(ModelForm):
+            class Meta:
+                model = ModelTest
+                optional_validator = None
+
+        form = ModelTestForm()
+        assert form.test_column.validators == []
+
     def test_override_unique_validator(self):
         class ModelTest(self.base):
             __tablename__ = 'model_test'
